@@ -84,7 +84,7 @@ class OpenLineageAdapter(LoggingMixin):
                     "OpenLineage configuration found. Transport type: `%s`",
                     config.get("type", "no type provided"),
                 )
-                self._client = OpenLineageClient(config=config)
+                self._client = OpenLineageClient(config=config)  # type: ignore[call-arg]
             else:
                 self.log.debug(
                     "OpenLineage configuration not found directly in Airflow. "
@@ -115,11 +115,11 @@ class OpenLineageAdapter(LoggingMixin):
             return yaml.safe_load(config_file)
 
     @staticmethod
-    def build_dag_run_id(dag_id: str, logical_date: datetime) -> str:
+    def build_dag_run_id(dag_id: str, logical_date: datetime, clear_number: int) -> str:
         return str(
             generate_static_uuid(
                 instant=logical_date,
-                data=f"{conf.namespace()}.{dag_id}".encode(),
+                data=f"{conf.namespace()}.{dag_id}.{clear_number}".encode(),
             )
         )
 
@@ -128,12 +128,13 @@ class OpenLineageAdapter(LoggingMixin):
         dag_id: str,
         task_id: str,
         try_number: int,
-        execution_date: datetime,
+        logical_date: datetime,
+        map_index: int,
     ):
         return str(
             generate_static_uuid(
-                instant=execution_date,
-                data=f"{conf.namespace()}.{dag_id}.{task_id}.{try_number}".encode(),
+                instant=logical_date,
+                data=f"{conf.namespace()}.{dag_id}.{task_id}.{try_number}.{map_index}".encode(),
             )
         )
 
@@ -156,10 +157,10 @@ class OpenLineageAdapter(LoggingMixin):
                 stack.enter_context(Stats.timer("ol.emit.attempts"))
                 self._client.emit(redacted_event)
                 self.log.debug("Successfully emitted OpenLineage event of id %s", event.run.runId)
-        except Exception as e:
+        except Exception:
             Stats.incr("ol.emit.failed")
             self.log.warning("Failed to emit OpenLineage event of id %s", event.run.runId)
-            self.log.debug("OpenLineage emission failure: %s", e)
+            self.log.debug("OpenLineage emission failure: %s", exc_info=True)
 
         return redacted_event
 
@@ -332,6 +333,7 @@ class OpenLineageAdapter(LoggingMixin):
         nominal_end_time: str,
         owners: list[str],
         run_facets: dict[str, RunFacet],
+        clear_number: int,
         description: str | None = None,
         job_facets: dict[str, JobFacet] | None = None,  # Custom job facets
     ):
@@ -348,8 +350,7 @@ class OpenLineageAdapter(LoggingMixin):
                 ),
                 run=self._build_run(
                     run_id=self.build_dag_run_id(
-                        dag_id=dag_id,
-                        logical_date=logical_date,
+                        dag_id=dag_id, logical_date=logical_date, clear_number=clear_number
                     ),
                     job_name=dag_id,
                     nominal_start_time=nominal_start_time,
@@ -373,6 +374,7 @@ class OpenLineageAdapter(LoggingMixin):
         run_id: str,
         end_date: datetime,
         logical_date: datetime,
+        clear_number: int,
         dag_run_state: DagRunState,
         task_ids: list[str],
     ):
@@ -383,8 +385,7 @@ class OpenLineageAdapter(LoggingMixin):
                 job=self._build_job(job_name=dag_id, job_type=_JOB_TYPE_DAG),
                 run=Run(
                     runId=self.build_dag_run_id(
-                        dag_id=dag_id,
-                        logical_date=logical_date,
+                        dag_id=dag_id, logical_date=logical_date, clear_number=clear_number
                     ),
                     facets={
                         **get_airflow_state_run_facet(dag_id, run_id, task_ids, dag_run_state),
@@ -408,6 +409,7 @@ class OpenLineageAdapter(LoggingMixin):
         run_id: str,
         end_date: datetime,
         logical_date: datetime,
+        clear_number: int,
         dag_run_state: DagRunState,
         task_ids: list[str],
         msg: str,
@@ -421,6 +423,7 @@ class OpenLineageAdapter(LoggingMixin):
                     runId=self.build_dag_run_id(
                         dag_id=dag_id,
                         logical_date=logical_date,
+                        clear_number=clear_number,
                     ),
                     facets={
                         "errorMessage": error_message_run.ErrorMessageRunFacet(
